@@ -7,7 +7,7 @@ fn integration_help_subcommand_check() {
         .args(&["--help"])
         .output()
         .expect("failed to display help text");
-    let output = output_to_string(help_output);
+    let output = output_to_string(help_output).unwrap();
 
     println!("output: {}", output);
 
