@@ -1,8 +1,11 @@
 mod common;
-
-use common::{output_to_string, test_dir_file, test_dir_with_subfolder, wash};
-use std::env::temp_dir;
-use std::fs::{remove_dir_all, remove_file};
+use assert_json_diff::assert_json_include;
+use common::{get_json_output, output_to_string, test_dir_file, test_dir_with_subfolder, wash};
+use serde_json::json;
+use std::{
+    env::temp_dir,
+    fs::{remove_dir_all, remove_file},
+};
 
 #[test]
 fn integration_claims_sign() {
@@ -49,7 +52,7 @@ fn integration_claims_sign() {
         .expect("failed to sign echo module");
     assert!(sign_echo.status.success());
     assert_eq!(
-        output_to_string(sign_echo),
+        output_to_string(sign_echo).unwrap(),
         format!(
             "Successfully signed {} with capabilities: wasmcloud:httpserver\n",
             signed_wasm_path.to_str().unwrap()
@@ -104,14 +107,24 @@ fn integration_claims_inspect() {
         .output()
         .expect("failed to inspect local wasm");
     assert!(local_inspect.status.success());
-    let local_inspect_output = output_to_string(local_inspect);
-    assert!(local_inspect_output.contains(&format!("\"account\":\"{}\"", ECHO_ACC)));
-    assert!(local_inspect_output.contains(&format!("\"module\":\"{}\"", ECHO_MOD)));
-    assert!(local_inspect_output.contains("\"can_be_used\":\"immediately\""));
-    assert!(local_inspect_output.contains("\"capabilities\":[\"HTTP Server\"]"));
-    assert!(local_inspect_output.contains("\"expires\":\"never\""));
-    assert!(local_inspect_output.contains("\"tags\":\"None\""));
-    assert!(local_inspect_output.contains("\"version\":\"0.2.1\""));
+
+    let local_inspect_output = get_json_output(local_inspect).unwrap();
+
+    let expected_inspect_output = json!({
+            "account": ECHO_ACC,
+            "module": ECHO_MOD,
+            "can_be_used": "immediately",
+            "capabilities": ["HTTP Server"],
+            "expires": "never",
+            "tags": "None",
+            "version": "0.2.1"
+
+    });
+
+    assert_json_include!(
+        actual: local_inspect_output,
+        expected: expected_inspect_output.clone()
+    );
 
     let local_reg_inspect = wash()
         .args(&[
@@ -125,14 +138,12 @@ fn integration_claims_inspect() {
         .output()
         .expect("failed to inspect local registry wasm");
     assert!(local_reg_inspect.status.success());
-    let local_reg_inspect_output = output_to_string(local_reg_inspect);
-    assert!(local_reg_inspect_output.contains(&format!("\"account\":\"{}\"", ECHO_ACC)));
-    assert!(local_reg_inspect_output.contains(&format!("\"module\":\"{}\"", ECHO_MOD)));
-    assert!(local_reg_inspect_output.contains("\"can_be_used\":\"immediately\""));
-    assert!(local_reg_inspect_output.contains("\"capabilities\":[\"HTTP Server\"]"));
-    assert!(local_reg_inspect_output.contains("\"expires\":\"never\""));
-    assert!(local_reg_inspect_output.contains("\"tags\":\"None\""));
-    assert!(local_reg_inspect_output.contains("\"version\":\"0.2.1\""));
+    let local_reg_inspect_output = get_json_output(local_reg_inspect).unwrap();
+
+    assert_json_include!(
+        actual: local_reg_inspect_output,
+        expected: expected_inspect_output.clone()
+    );
 
     let remote_inspect = wash()
         .args(&[
@@ -147,14 +158,12 @@ fn integration_claims_inspect() {
         .output()
         .expect("failed to inspect local registry wasm");
     assert!(remote_inspect.status.success());
-    let remote_inspect_output = output_to_string(remote_inspect);
-    assert!(remote_inspect_output.contains(&format!("\"account\":\"{}\"", ECHO_ACC)));
-    assert!(remote_inspect_output.contains(&format!("\"module\":\"{}\"", ECHO_MOD)));
-    assert!(remote_inspect_output.contains("\"can_be_used\":\"immediately\""));
-    assert!(remote_inspect_output.contains("\"capabilities\":[\"HTTP Server\"]"));
-    assert!(remote_inspect_output.contains("\"expires\":\"never\""));
-    assert!(remote_inspect_output.contains("\"tags\":\"None\""));
-    assert!(remote_inspect_output.contains("\"version\":\"0.2.1\""));
+    let remote_inspect_output = get_json_output(remote_inspect).unwrap();
+
+    assert_json_include!(
+        actual: remote_inspect_output,
+        expected: expected_inspect_output
+    );
 
     remove_dir_all(inspect_dir).unwrap();
 }
@@ -196,14 +205,21 @@ fn integration_claims_inspect_cached() {
         .output()
         .expect("failed to inspect remote cached registry");
     assert!(remote_inspect.status.success());
-    let remote_inspect_output = output_to_string(remote_inspect);
-    assert!(remote_inspect_output.contains(&format!("\"account\":\"{}\"", ECHO_ACC)));
-    assert!(remote_inspect_output.contains(&format!("\"module\":\"{}\"", ECHO_MOD)));
-    assert!(remote_inspect_output.contains("\"can_be_used\":\"immediately\""));
-    assert!(remote_inspect_output.contains("\"capabilities\":[\"HTTP Server\"]"));
-    assert!(remote_inspect_output.contains("\"expires\":\"never\""));
-    assert!(remote_inspect_output.contains("\"tags\":\"None\""));
-    assert!(remote_inspect_output.contains("\"version\":\"0.2.1\""));
+    let remote_inspect_output = get_json_output(remote_inspect).unwrap();
+    let expected_inspect_output = json!({
+        "account": ECHO_ACC,
+        "module": ECHO_MOD,
+        "can_be_used": "immediately",
+        "capabilities": ["HTTP Server"],
+        "expires": "never",
+        "tags": "None",
+        "version": "0.2.1"
+    });
+
+    assert_json_include!(
+        actual: remote_inspect_output,
+        expected: expected_inspect_output
+    );
 
     let remote_inspect_no_cache = wash()
         .args(&[
@@ -274,7 +290,7 @@ fn integration_claims_call_alias() {
         .expect("failed to sign logger module");
     assert!(sign_logger.status.success());
     assert_eq!(
-        output_to_string(sign_logger),
+        output_to_string(sign_logger).unwrap(),
         format!(
             "Successfully signed {} with capabilities: wasmcloud:httpserver,wasmcloud:logging\n",
             signed_wasm_path.to_str().unwrap()
@@ -293,17 +309,19 @@ fn integration_claims_call_alias() {
         .output()
         .expect("failed to inspect local wasm");
     assert!(local_inspect.status.success());
-    let local_inspect_output = output_to_string(local_inspect);
-    assert!(local_inspect_output.contains(&format!("\"account\":\"{}\"", ACC_PKEY)));
-    assert!(local_inspect_output.contains(&format!("\"module\":\"{}\"", MOD_PKEY)));
-    assert!(local_inspect_output.contains("\"can_be_used\":\"immediately\""));
-    assert!(local_inspect_output.contains("\"capabilities\":["));
-    assert!(local_inspect_output.contains("\"HTTP Server\""));
-    assert!(local_inspect_output.contains("\"Logging\""));
-    assert!(local_inspect_output.contains("\"expires\":\"never\""));
-    assert!(local_inspect_output.contains("\"tags\":\"None\""));
-    assert!(local_inspect_output.contains("\"version\":\"None\""));
-    assert!(local_inspect_output.contains("\"call_alias\":\"wasmcloud/logger_onedotzero\""));
+    let local_inspect_output = get_json_output(local_inspect).unwrap();
+    let expected_json = json!({
+        "account": ACC_PKEY,
+        "module": MOD_PKEY,
+        "can_be_used": "immediately",
+        "capabilities": ["HTTP Server", "Logging"],
+        "expires": "never",
+        "tags": "None",
+        "version": "None",
+        "call_alias": "wasmcloud/logger_onedotzero"
+    });
+
+    assert_json_include!(actual: local_inspect_output, expected: expected_json);
 
     remove_dir_all(call_alias_dir).unwrap();
 }
